==> haskell-persistent-sqlite-2.13.1.1-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   persistent-sqlite
version:                2.13.1.1
visibility:             public
id:                     persistent-sqlite-2.13.1.1-4FZbNKq6B3BGenUipYYrbp
key:                    persistent-sqlite-2.13.1.1-4FZbNKq6B3BGenUipYYrbp
license:                MIT
maintainer:             Michael Snoyman <michael@snoyman.com>
author:                 Michael Snoyman <michael@snoyman.com>
stability:              Stable
homepage:               http://www.yesodweb.com/book/persistent
synopsis:               Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.

category:               Database, Yesod
abi:                    b0854127089e02e6994c8d1cb9861011
exposed:                True
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite Database.Sqlite.Internal

import-dirs:            /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.1
library-dirs:           /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.1
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.1
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-persistent-sqlite
hs-libraries:           HSpersistent-sqlite-2.13.1.1-4FZbNKq6B3BGenUipYYrbp
extra-libraries:        pthread sqlite3
extra-libraries-static: sqlite3 m z
depends:
    aeson-2.1.2.1-FurzwiqHIOZ8NUBnR3RWtD base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-E5Krv6RV3hBBPS0slvyYkr
    containers-0.6.7 microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669
    monad-logger-0.3.42-9wN21l2PI338h9NA8VK0Z1 mtl-2.2.2
    persistent-2.14.5.1-3cWHiOJ5F2N5xPqfcKrao6
    resource-pool-0.2.3.2-Ce97ZEeGrzj5HsY77vKl7e
    resourcet-1.2.6-KSdJbGYyd3pAgG4RlfssrZ text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-3ZBRQjn1NdW5zFXXpEAC63

haddock-interfaces:
    /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock

haddock-html:           /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-sqlite-2.13.1.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   persistent-sqlite
version:                2.13.1.1
visibility:             public
id:                     persistent-sqlite-2.13.1.1-3bCWGQtOs36LwubIDgVFGQ
key:                    persistent-sqlite-2.13.1.1-3bCWGQtOs36LwubIDgVFGQ
license:                MIT
maintainer:             Michael Snoyman <michael@snoyman.com>
author:                 Michael Snoyman <michael@snoyman.com>
stability:              Stable
homepage:               http://www.yesodweb.com/book/persistent
synopsis:               Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.

category:               Database, Yesod
abi:                    41bd6229982759b0f38e453c936d3991
exposed:                True
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite Database.Sqlite.Internal

import-dirs:            /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.1
library-dirs:           /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.1
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.1
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-persistent-sqlite
hs-libraries:           HSpersistent-sqlite-2.13.1.1-3bCWGQtOs36LwubIDgVFGQ
extra-libraries:        pthread sqlite3
extra-libraries-static: sqlite3 m z
depends:
    aeson-2.1.2.1-FurzwiqHIOZ8NUBnR3RWtD base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-E5Krv6RV3hBBPS0slvyYkr
    containers-0.6.7 microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669
    monad-logger-0.3.42-9wN21l2PI338h9NA8VK0Z1 mtl-2.2.2
    persistent-2.14.5.2-1RDSwVfe5AMK8SJJ4K4zxo
    resource-pool-0.2.3.2-Ce97ZEeGrzj5HsY77vKl7e
    resourcet-1.2.6-KSdJbGYyd3pAgG4RlfssrZ text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-3ZBRQjn1NdW5zFXXpEAC63

haddock-interfaces:
    /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock

haddock-html:           /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
